##  Manual Linking of Discovered Applications to Fact Sheets
Discovered applications that are not automatically linked can be linked manually. To manually link a discovered item, do the following:
  1. From the list, click on the discovered item that needs to be linked. This opens the side panel with additional information about the system, along with fact sheet suggestions.
  2. In the side panel, review the details about the SaaS application to decide whether and to which fact sheet the item should be linked. The Details tab provides additional information you might need.
![Manually Linking the Discovered SaaS Item to the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e98f67a4410148082a2b4fe032486_LowRes.png)
Manually Linking the Discovered SaaS Item to the Fact Sheet
  3. The system suggests a matching fact sheet to link; check if it is the appropriate one. If the system has not found a suitable matching fact sheet, a new fact sheet is created upon completing the linking process.
  4. If you want to link the item to a different fact sheet than the suggested one:
    1. Hover over the suggested fact sheet.
    2. Click Edit.
    3. Search and select the desired fact sheet. You can link it to either an application or an IT component fact sheet.
  5. Click Link to finish establishing the link.
